﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.DataProcessor;
using HeuristicLab.PluginInfrastructure;


namespace HeuristicLab.DataImporter.DataProcessor {
  public partial class ImportDialog : Form {
    private CommandChain commandChain;
    private Data.Model.DataSet dataSet;
    public ImportDialog(Data.Model.DataSet dataSet, CommandChain commandChain) {
      InitializeComponent();
      this.dataSet = dataSet;
      this.commandChain = commandChain;
      IImporter[] importers = ApplicationManager.Manager.GetInstances<IImporter>().ToArray();
      this.importerListBox.DataSource = importers;
    }

    private void btnOK_Click(object sender, EventArgs e) {
      this.Cursor = Cursors.WaitCursor;
      try {
        ICommand cmd = ((IImporter)importerListBox.SelectedItem).CreateImportCommand(this.dataSet);
        this.commandChain.Add(cmd);
      }
      catch (CommandExecutionException cee) {
        MessageBox.Show(cee.Message, cee.Command.Description);
      }
      finally {
        this.Cursor = Cursors.Default;
      }
    }

    private void importerListBox_SelectedIndexChanged(object sender, EventArgs e) {
      this.settingsPanel.Controls.Clear();
      UserControl ctrl = ((IImporter)importerListBox.SelectedItem).SettingsControl;
      this.Height = 180 + ctrl.Height;
      this.settingsPanel.Controls.Add(ctrl);
    }
  }
}
